@@ -31,11 +31,12 @@
 #' @export
 ScatterBoxPlot = function(frm, xvar, yvar, title, ...,
                           pt_alpha=0.3) {
-  frm <- check_frame_args_list(...,
-                               frame = frm,
-                               name_var_list = list(xvar = xvar, yvar = yvar),
-                               title = title,
-                               funname = "WVPlots::ScatterBoxPlot")
+  frm <- as.data.frame(frm)
+  check_frame_args_list(...,
+                        frame = frm,
+                        name_var_list = list(xvar = xvar, yvar = yvar),
+                        title = title,
+                        funname = "WVPlots::ScatterBoxPlot")
   if(!isDiscrete(frm[[xvar]])) {
     stop(paste(xvar, "should be discrete (factor, character, integer, or logical)"))
   }
@@ -84,11 +85,12 @@ ScatterBoxPlot = function(frm, xvar, yvar, title, ...,
 ScatterBoxPlotH = function(frm, xvar, yvar, title,
                            ...,
                            pt_alpha=0.3) {
-  frm <- check_frame_args_list(...,
-                               frame = frm,
-                               name_var_list = list(xvar = xvar, yvar = yvar),
-                               title = title,
-                               funname = "WVPlots::ScatterBoxPlotH")
+  frm <- as.data.frame(frm)
+  check_frame_args_list(...,
+                        frame = frm,
+                        name_var_list = list(xvar = xvar, yvar = yvar),
+                        title = title,
+                        funname = "WVPlots::ScatterBoxPlotH")
   ScatterBoxPlot(frm, yvar, xvar, title=title, ...,
                  pt_alpha=pt_alpha) + ggplot2::coord_flip()
 }
